// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

#ifndef OB_UTIL_H
#define OB_UTIL_H

// XXX Are these necessary?
//
// Forward declarations
//
namespace IOP
{

struct IOR;
struct TaggedComponent;

} // End of namespace IOP

namespace CORBA
{

class Object;
typedef Object* Object_ptr;

} // End of namespace CORBA


namespace OB
{

//
// The message viewer class
//
class MessageViewer
{
    //
    // Hide copy-constructor and assignment operator
    //
    MessageViewer(const MessageViewer&);
    void operator=(const MessageViewer&);

protected:

    //
    // The message viewer singleton
    //
    static OB_IMPORT MessageViewer* instance_;
    friend class MessageViewerDestroyer;

    //
    // The message viewer trace level
    //
    static int traceLevel_;

    MessageViewer() { }
    virtual ~MessageViewer() { }

public:

    //
    // Get the message viewer singleton
    //
    static MessageViewer* instance();

    //
    // Set and get the viewers trace level
    //
    static int getTraceLevel();
    static void setTraceLevel(int);

    //
    // Print messages
    //
    virtual void message(const char*);
    virtual void error(const char*);
    virtual void warning(const char*);
    virtual void nca(const char*);
    virtual void trace(int, const char*);
};

//
// Print system exception
// Get stringified system exception
//
void PrintException(const CORBA::SystemException&);
char* ExceptionToString(const CORBA::SystemException&);

//
// Print octets for debug reasons
//
void PrintOctets(OB_STD(ostream)&, const CORBA::Octet*, CORBA::ULong);

//
// Print object reference
//
void PrintObjref(OB_STD(ostream)&, CORBA::Object_ptr);
void PrintObjref(OB_STD(ostream)&, const char*);
void PrintObjref(OB_STD(ostream)&, const IOP::IOR&);

//
// Print code set information
//
void PrintTagCodeSets(OB_STD(ostream)&, const IOP::TaggedComponent&);

//
// Add code set information
//
void IOPAddCodeSetInformation(IOP::IOR*, CORBA::ULong, CORBA::ULong);
} // End of namespace OB

#endif
